# A SNAQL Based Query Engine

This project is a fork of the SNAQL project, where we hope to add the ability to pass in an optional function to 
execute the query when the query is called (delivers the data instead of the query string). 

## Installation

For now, you'll have to clone locally to use. We plan to have this available in PyPI, but this will be our first
attempt. 

## Documentation

You always can find the most recent docs with examples for SNAQL on [Snaql GitBook](https://semirook.gitbooks.io/snaql/content/).
Semirook's documents are fantastic, and the SQL templating is still the main knowlege you need.
We will add the requirements for the SQL engine once we have the details worked out.

